@@ -1,10 +1,22 @@
 
-from django.shortcuts import render, redirect
-from django.utils.translation import ugettext_lazy as _
+from django.shortcuts import render, redirect, Http404
+from django.contrib.sitemaps.views import sitemap
 
 from seo.models import RedirectRecord, ErrorRecord
 
 
+def sitemap_download(request):
+    try:
+        from core.sitemaps import CommonSitemap
+        return sitemap(request, {'generic': CommonSitemap})
+    except ImportError:
+        return Http404()
+
+
+def sitemap_tree(request):
+    return render(request, 'sitemap.html')
+
+
 def page_not_found(request, **kwargs):
 
     path = request.path
